@@ -106,6 +106,7 @@ static struct {
 	int verfexit;
 	int noenvcheck;
 	int quiet;
+	int debugscans;
       #ifdef UNIX
 	int xwindows;	/* run in xwindows mode */
 	int console;	/* run in console mode */
@@ -139,7 +140,7 @@ CopyRight( int level )
 		    "W-Minimal-Editor"
 		  #endif
 		    " v" VERSION
-		    "; Copyright (C) 1991-96 by Werner Koch (dd9jn)" ; break;
+		    "; Copyright (C) 1991-96,98 by Werner Koch (dd9jn)" ; break;
       case 14:	p =   VERSION ; break;
       case 11:	p = "Usage: w [options] [files] (-h for help)";
 		break;
@@ -171,6 +172,7 @@ CopyRight( int level )
     " -v       = request exit confirmation\n"
     " -b       = force black & white mode\n"
     " -q       = quiet (do not print copyright message)\n"
+    " -Jdbgscan = print keyboard scancodes on stderr\n"
     " --       = stop option processing\n"
     " -h       = help\n";
 	break;
@@ -204,6 +206,8 @@ CopyRight( int level )
 	    "OS/2 1.x Version"
 	  #elif EMX
 	    "EMX Version"
+	  #elif WINNT
+	    "Windoze NT Version"
 	  #elif DOS16RM
 	    "DOS16RM Version"
 	  #elif __linux__
@@ -253,7 +257,10 @@ int
 main( int argc, char **argv )
 {
     char  *s ;
-    int  err=0, loadDirFlag, i, have_xargs;
+    int  err=0, loadDirFlag, i;
+  #ifdef UNIX
+    int have_xargs;
+  #endif
     char *pgmname;
 
     Enter_Main();
@@ -324,6 +331,13 @@ main( int argc, char **argv )
 		  case 'v' : opt.verfexit++; break;
 		  case 'b' : opt.blackWhite = 1; break;
 		  case 'q' : opt.quiet=1; break;
+		  case 'J' :
+		    if( !strcmp(s+1,"dbgscan" ) )
+			opt.debugscans++;
+		    else
+			Error(3,GetStr(15),s );
+		    while( *s ) s++; s--;
+		    break;
 		  case 'h' :
 		  case '?' : CopyRight(0) ; CopyRight(2); break;
 		  default  : Error(3,GetStr(15),s );
@@ -381,6 +395,9 @@ main( int argc, char **argv )
     }
   #endif
 
+    if( opt.debugscans )
+	KybrdDrvSetDebug( 1 );
+
   #if !(__STDC__ || OS2)
     setbuf( stdprn, NULL );
   #endif
@@ -788,6 +805,7 @@ const char *GetErrorString( int n )
       case ERR_BUG	: p = "Internal error - recovered"; break;
       case ERR_VIEW	: p = "Can't do this in view-mode"; break;
       case ERR_INVCP	: p = "CodePage not available"; break;
+      case ERR_BUGDB	: p = "Problem with BugDB"; break;
       default:	sprintf(buf, "Error %d", n ); p = buf; break;
     }
     return p;
@@ -941,6 +959,152 @@ int putenv(const char *a)
 {
     return 0;  /* there is an error in the current DOSX Impl. */
 }	       /* which causes a GP (possible ill addr) */
+#elif defined(UNIX)
+/*
+ * We use our own putenv/environment system
+ * because the use of environ, getenv() and putenv is not well defined
+ * I think - Without these functions the environment is messed up.
+ */
+
+static char **environ_array;
+
+char **
+GetEnvironmentArray(void)
+{
+    extern char **environ;
+    char **ep;
+    int i, len;
+
+    if( !environ_array ) {
+	/* copy it from the parent environment */
+	for(i=0,ep=environ; *ep; ep++, i++ )
+	    ;
+	i++;
+	len = i + 10;
+	environ_array = xmalloc( len * sizeof *environ_array );
+	for(i=0,ep=environ; *ep; ep++, i++ )
+	    environ_array[i] = xstrdup(*ep);
+	for( ; i < len ; i++ )
+	    environ_array[i] = NULL;
+	environ_array[i-1] = "+++"; /* this marks the end of the gap */
+    }
+    return environ_array;
+}
+
+const char *
+GetEnvironmentStrings(void)
+{
+    static char *env;
+    static size_t envSize;
+    char **pp, **pporg;
+    char *p;
+    size_t n;
+
+    if( !environ_array )
+	GetEnvironmentArray();
+
+    /* determine needed space */
+    pporg = environ_array;
+    for(n = 0, pp = pporg; *pp ; pp++ )
+	n += strlen( *pp ) + 1;
+    n += 3; /* add extra 0 plus 2 for security */
+    if( !env || n != envSize ) { /* first call or size changed */
+	free( env );
+	env = xmalloc( envSize = n );
+    }
+    /* copy to space */
+    for(p = env, pp = pporg; *pp ; pp++ )
+	if( **pp )
+	    p = stpcpy(p, *pp) + 1;
+    *p++ = 0;  /* terminating 0 */
+    *p++ = 0;  /* plus two extras */
+    *p	 = 0;
+    return env;
+}
+
+char *
+getenv(const char *name)
+{
+    const size_t len = strlen(name);
+    char **ep;
+    static int sentinel;
+
+    if( !environ_array ) {
+	if( sentinel ) { /* may happen because lib functions may use getenv*/
+	    extern char **environ;
+	    /* return value from the original environment */
+	    for(ep = environ; *ep ; ep++ )
+		if( !strncmp( *ep, name, len) && (*ep)[len] == '=' )
+		    return (*ep)+len+1;
+	    return NULL;
+	}
+	sentinel++;
+	GetEnvironmentArray();
+	sentinel--;
+    }
+
+    for(ep = environ_array; *ep ; ep++ )
+	if( !strncmp( *ep, name, len) && (*ep)[len] == '=' )
+	    return (*ep)+len+1;
+    return NULL;
+}
+
+int
+putenv(const char *string)
+{
+    size_t len;
+    char **ep, **dp;
+    const char *se = strchr( string, '=' );
+
+    if( !environ_array )
+	GetEnvironmentArray();
+
+    if( !se ) { /* remove this var */
+	len = strlen(string);
+	for(ep = environ_array; *ep ; ep++ )
+	    if( !strncmp( *ep, string, len) && (*ep)[len] == '=' ) {
+		free(*ep);
+		for(dp=ep; (dp[0] = dp[1]); dp++ )
+		    ;
+		break;
+	    }
+	return 0;
+    }
+    else { /* add this variable */
+	char *newstr;
+	len = se - string;
+
+	if( !(newstr=strdup(string)) )
+	    return -1;
+	for(ep = environ_array; *ep ; ep++ )
+	    if( !strncmp( *ep, string, len) && (*ep)[len] == '=' ) {
+		free(*ep);
+		*ep = newstr;
+		return 0;
+	    }
+	/* mut put a new entry into the array */
+	*ep++ = newstr;
+	if( *ep ) { /* this is the marker for the end of the gap */
+		    /* we must allocate a new array */
+	    char **newenv;
+	    int i;
+
+	    i = ep - environ_array;
+	    i++;
+	    len = i + 10;
+	    newenv = xmalloc( len * sizeof *newenv );
+	    for(i=0,dp=environ_array; dp < ep ; dp++, i++ )
+		newenv[i] = *dp;
+	    for( ; i < len ; i++ )
+		newenv[i] = NULL;
+	    newenv[i-1] = "+++"; /* this marks the end of the gap */
+	    free(environ_array);
+	    environ_array = newenv;
+	}
+    }
+
+    return 0;
+}
 
 #endif
 
