@@ -35,6 +35,7 @@ static struct {
 	const byte flag;	/* 0 = n Woerter, keine Paramter */
 				/* 1 = 1 Wort dann Paramter */
 				/* 2 = 2 Woerter dann Paramter */
+				/* 3 = 3 Woerter dann Paramter */
 	const char *strg;	/* must be sorted by the first character */
 				/* and in lowercase */
 	byte  strgLen;		/* this will be filled in at runtime */
@@ -87,6 +88,7 @@ static struct {
 { CMD_BOTTOM		 , ARGTYPE_NO	  , 0, "bottom"           },
 { CMD_BEEP		 , ARGTYPE_NO	  , 0, "bp"               },
 { CMD_BACKTAB		 , ARGTYPE_NO	  , 0, "bt"               },
+{ CMD_BUG		 , ARGTYPE_STRORVAR,1, "bug"              },
 { CMD_BACKTAB_WORD	 , ARGTYPE_STRORVAR,1, "bw"               },
 { CMD_CHANGE		 , ARGTYPE_CHG	  , 1, "c"                },
 { CMD_CURSOR_DATA	 , ARGTYPE_NO	  , 0, "ca"               },
@@ -301,6 +303,7 @@ static struct {
 { CMD_SET_HILITE	 , ARGTYPE_FILE   , 2, "set hilite"       },
 { CMD_SET_HISTORY	 , ARGTYPE_NUMBER , 2, "set history"      },
 { CMD_SET_HSCROLL	 , ARGTYPE_ONOFF  , 2, "set hscroll"      },
+{ CMD_SET_IGNORE_BACKUPS , ARGTYPE_ONOFF  , 3, "set ignore backups" },
 { CMD_SET_INTCLIP	 , ARGTYPE_ONOFF  , 2, "set intclip"      },
 { CMD_SET_KEYPREFIX	 , ARGTYPE_STRING , 2, "set keyprefix"    },
 { CMD_SET_LABEL 	 , ARGTYPE_STRING , 2, "set label"        },
