@@ -162,11 +162,11 @@ static struct {
   /*112  not used */
   /*113  not used */
   /*114  not used */
-  /*115  not used */
-  /*116  not used */
-  /*117  not used */
+  { 115, K_SUPER_L			},
+  { 116, K_SUPER_R			},
+  { 117, K_HYPER_R			},
   /*118  not used */
-  { 119, K_PAUSE			}
+  { 119, K_PAUSE			},
 };
 
 /* Shift keys are not included: */
@@ -282,10 +282,13 @@ static int isInitialized;
 static char prefixNextKey;
 static int translateCodes;
 static DEADKEY deadkeys;
+static ushort	multi_key;
+static ushort	pendingMulti;
 static ushort	pendingScan;
 static unsigned pendingFlag;
 static ushort	pendingChar;
 static int	pendingBaseCode;
+static unsigned debugflags;
 
 
 #if USE_VT_LINUX
@@ -341,7 +344,7 @@ GetBaseCode( ushort scan )
 
 /****************
  * Special handling for the pad keys
- * Out definition is:
+ * Our definition is:
  *    In ancient PC times there where only the pad-keys.
  */
 
@@ -425,6 +428,13 @@ KybrdDrvSetTrans( int mode )
 }
 
 
+void
+KybrdDrvSetDebug( unsigned flags )
+{
+    debugflags = flags;
+}
+
+
 void
 KybrdDrvSetPrefix( char pref )
 {
@@ -478,7 +488,18 @@ KybrdDrvGetKeyId( int *ret_value )
     if( flag & 128 )
 	kstate |= K_FLAG_MOUSE;
 
-    if( !pendingScan ) {
+    if( !pendingMulti && multi_key && scan == multi_key )  {
+	pendingMulti = 1;
+	return 0;
+    }
+
+    if( pendingMulti && !chr )
+	return 0;  /* ingore all non-character keys */
+
+    if( !pendingScan && multi_key && !pendingMulti )
+	;
+    else if( !pendingScan ) {
+	pendingMulti = 0;
 	if( scan && !(kstate & ~(K_FLAG_SHIFT|K_FLAG_CTRL|K_FLAG_ALT)) ) {
 	    ks = kstate & (K_FLAG_SHIFT|K_FLAG_CTRL|K_FLAG_ALT);
 	    for(d=deadkeys; d; d = d->next )
@@ -492,6 +513,7 @@ KybrdDrvGetKeyId( int *ret_value )
 	}
     }
     else {
+	pendingMulti = 0;
 	d = NULL;
 	if( scan && !(kstate & ~(K_FLAG_SHIFT|K_FLAG_CTRL|K_FLAG_ALT)) ) {
 	    ks = kstate & (K_FLAG_SHIFT|K_FLAG_CTRL|K_FLAG_ALT);
@@ -598,27 +620,25 @@ KybrdDrvGetKeyId( int *ret_value )
     }
   #endif
 
- #if 0	/* debug it */
-    {
+    if( debugflags & 1 ) {
 	const char *s;
 
-	printf( "scan %3d  char %3d  key %3d", (int)scan, (int)chr, baseCode );
+	fprintf(stderr, "scan %3d  char %3d  key %3d", (int)scan, (int)chr, baseCode );
 	if( kstate & K_FLAG_SHIFT )
-	    fputs( " shift", stdout);
+	    fputs( " shift", stderr);
 	if( kstate & K_FLAG_CTRL )
-	    fputs( " ctrl", stdout);
+	    fputs( " ctrl", stderr);
 	if( kstate & K_FLAG_ALT   )
-	    fputs( " alt ", stdout);
+	    fputs( " alt ", stderr);
 	if( kstate & K_FLAG_COMPOSE )
-	    fputs( " comp", stdout);
+	    fputs( " comp", stderr);
 	if( *(s = WklibKeyCode2String(baseCode)) )
-	    printf( " (%s)\n", WklibKeyCode2String(baseCode) );
+	    fprintf(stderr, " (%s)\n", WklibKeyCode2String(baseCode) );
 	else if( baseCode < 256 )
-	    printf( " (%c)\n", baseCode );
+	    fprintf(stderr, " (%c)\n", baseCode );
 	else
-	    putchar('\n');
+	    putc('\n',stderr);
     }
-  #endif
 
     /* create the keyid */
     keyid = baseCode;
@@ -683,6 +703,8 @@ KybrdDrvGetKeyId( int *ret_value )
  *  "compose" modifier <first> modifier <second> <value>
  *	      [ modifier <scan> ]
  *
+ *  "multikey"  multikey_scancode
+ *
  *  with modifier := ["shift"|"ctrl"|"alt"]
  *
  * where the constant "scan" identifies this as a scancode definition,
@@ -745,6 +767,7 @@ KybrdDrvDefKey(char *buffer)
 	p = p2;
 	sone = stwo = sfakescan = 0;
 	fakescan = 0;
+
 	if( !(p = ParseKeyDefValue(p, &one,2))	)
 	    return ERR_INVARG;
 	if( one <= -10 ) {
@@ -807,6 +830,14 @@ KybrdDrvDefKey(char *buffer)
 	    d->state = sfakescan & 0xff;
 	}
     }
+    else if( !stricmp( p, "composekey") ) {
+	int smulti;
+
+	p = p2;
+	if( !(p = ParseKeyDefValue(p, &smulti, 0 )) )
+	    return ERR_INVARG;
+	multi_key = smulti;
+    }
     else
 	return ERR_INVARG;
 
@@ -817,7 +848,7 @@ KybrdDrvDefKey(char *buffer)
 /****************
  * mode 0 := parse a scancode
  *	1 := parse a value
- *	2 := pase a scancode or a string
+ *	2 := parse a scancode or a string
  * Returns: NULL := Error
  *	 *ret_value >= 0 := scancode or keyvalue
  *	 *ret_value == -1 := ignore
