@@ -1,5 +1,5 @@
 /* [wproc.c wk 29.7.91] W-Editor Dispatcher
- *	Copyright (c) 1991 by Werner Koch (dd9jn)
+ *	Copyright (c) 1991,1998 by Werner Koch (dd9jn)
  * This file is part of the W-Editor.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -88,6 +88,7 @@ static struct {
 	int intclip;	/* true = force using of internal clipboard */
 	int latin;
 	int editcmd;	/* on/off */
+	int ign_bkup;	/* ignore backups in directory listings */
     } setOptions;
 
 static char **history;	 /* each line ist malloced, */
@@ -207,6 +208,12 @@ int ProcessCmd( cmd_t *cmd )
 	break;
 
     #if W_FULL
+
+      case CMD_BUG:
+	err = Cmd_Bug( cmd );
+	break;
+
+
       case CMD_CENTER_IN_MARGINS:
 	err = Cmd_CenterInMargins();
 	break;
@@ -873,6 +880,7 @@ int ProcessCmd( cmd_t *cmd )
 	PutSetOption( SETOPT_BLANKSTRIP, cmd->arg.number );
 	break;
 
+
       case CMD_SET_CRTSAVE:
 	PutSetOption( SETOPT_CRTSAVE, cmd->arg.number );
 	break;
@@ -1099,7 +1107,7 @@ int ProcessCmd( cmd_t *cmd )
 	break;
 
       case CMD_UNLOCK:
-	UnlockFile( fileHd );
+	WeditUnlockFile( fileHd );
 	break;
 
       case CMD_SET_AUTOLOCK:
@@ -1216,6 +1224,10 @@ int ProcessCmd( cmd_t *cmd )
 	PutSetOption( SETOPT_EDITCMD, cmd->arg.number );
 	break;
 
+      case CMD_SET_IGNORE_BACKUPS:
+	PutSetOption( SETOPT_IGNORE_BACKUPS, cmd->arg.number );
+	break;
+
       default:
 	if( (err = SimpleCmds( cmd->cmd )) == -1 ) {
 	    err = ExecFunction( cmd );
@@ -1553,6 +1565,7 @@ int GetSetOption( int opt )
       case SETOPT_REFRESH:	r = setOptions.refresh;     break;
       case SETOPT_INTCLIP:	r = setOptions.intclip;     break;
       case SETOPT_LATIN:	r = setOptions.latin;	    break;
+      case SETOPT_IGNORE_BACKUPS: r = setOptions.ign_bkup;  break;
       case SETOPT_EDITCMD:	r = setOptions.editcmd;     break;
       default: Bug( "get: set option %d unkown", opt );
     }
@@ -1587,6 +1600,7 @@ void PutSetOption( int opt, int val )
       case SETOPT_REFRESH:	setOptions.refresh     = val; break;
       case SETOPT_INTCLIP:	setOptions.intclip     = val; break;
       case SETOPT_LATIN:	setOptions.latin       = val; break;
+      case SETOPT_IGNORE_BACKUPS: setOptions.ign_bkup  = val; break;
       case SETOPT_EDITCMD:	setOptions.editcmd     = val; break;
       default: Bug( "put: set option %d unkown", opt );
     }
@@ -1667,6 +1681,9 @@ const char *GetSetOptionString( int opt )
       case SETOPT_LATIN:
 	t = "latin"; u = setOptions.latin ? t_on:t_off;
 	break;
+      case SETOPT_IGNORE_BACKUPS:
+	t = "ignore backups"; u = setOptions.ign_bkup ? t_on:t_off;
+	break;
       case SETOPT_EDITCMD:
 	t = "editcmd"; u = setOptions.editcmd ? t_on:t_off;
 	break;
@@ -1872,6 +1889,7 @@ static int DoCommit( void )
 }
 
 
+
 /****************
  * This will be also be used from main() to load the files
  * from the commandline
@@ -2177,6 +2195,8 @@ DoEdit( const char *filename, int mode	)
 	  #endif
 	}
     }
+    if( !o.bin )
+	ExecFilesProfile(fHd);
 
   failure:
     free(string);
