@@ -25,7 +25,7 @@
  */
 
 #include "wtailor.h"
-RCSID("$Id: wsrch.c,v 1.9 1996/05/17 18:49:51 wernerk Exp $")
+RCSID("$Id: wsrch.c,v 1.10 1996/11/08 13:08:54 wk Exp $")
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -217,7 +217,11 @@ DoLocate( const char *pattern, int *changeMode,
 		if( firstPos )
 		    firstPos--;
 		endLine  = 0;
-		if( flg.left ) {
+		if( flg.left
+			   #if USE_REGEXP
+			     || flg.reg
+			   #endif
+					) {
 		    startPos = 0;
 		    endPos = MAX_LINELEN-1;
 		}
