@@ -100,6 +100,7 @@
 #define  ZNAMEID_SYSNAME   35
 #define  ZNAMEID_DOMAINNAME 36
 #define  ZNAMEID_SCREEN    37
+#define  ZNAMEID_ISODATE   38
 
 /******* typedefs ********/
 typedef struct {
@@ -150,6 +151,7 @@ static struct {
 	{ "ZScreen"     , ZNAMEID_SCREEN       } ,
 	{ "ZCTime"      , ZNAMEID_CTIME        } ,
 	{ "ZDate"       , ZNAMEID_DATE         } ,
+	{ "ZISODate"    , ZNAMEID_ISODATE      } ,
 	{ "ZTime"       , ZNAMEID_TIME         } ,
 	{ "ZCmdLine"    , ZNAMEID_CMDLINE      } ,
 	{ "ZInCmd"      , ZNAMEID_INCMD        } ,
@@ -948,6 +950,8 @@ static int DupValue()
  * Put a variable into the variable Table
  * if value is an empty string, the variable will be removed
  * Variable die mit Z anfangen sind ungltig mit folgenden Ausnahmen:
+ *   - ZPrf_<xxxx>
+ *   - ZPrfSh
  *   - ZEditPrc
  *   - ZEditPrc_<xxxx>
  *   - ZWordDel
@@ -966,6 +970,8 @@ static int PutVar( const char *name, const char *value )
     zWordDel = !strcmp( name, "ZWordDel" );
     if( !*name || toupper(*name) == 'Z' )
 	if( strncmp( name, "ZEditPrc", 8 ) &&
+	    strncmp( name, "ZPrf_", 5 ) &&
+	    strncmp( name, "ZPrfSh", 6 ) &&
 	    strncmp( name, "ZDefEditOpt", 11 ) &&
 	    strncmp( name, "ZDefSaveOpt", 11 ) && !zWordDel )
 	    return ERR_INVVAR;
@@ -1290,6 +1296,12 @@ GetVar( const char *txt, int argType )
 	    strftime(value,10, "%d.%m.%y", localtime(&tclock) );
 	    break;
 
+	  case ZNAMEID_ISODATE:
+	    time( &tclock );
+	    value = xmalloc( 20 );
+	    strftime(value,20, "%Y-%m-%d", localtime(&tclock) );
+	    break;
+
 	  case ZNAMEID_TIME:
 	    time( &tclock );
 	    value = xmalloc( 10 );
@@ -1324,7 +1336,8 @@ GetVar( const char *txt, int argType )
  * ffnet den file: .varlist und schreibe alle variablen hinein.
  */
 
-int Cmd_VarList( cmd_t *cmd )
+int
+Cmd_VarList( cmd_t *cmd )
 {
     int err=0, n, fhd;
     const char *name;
