@@ -1,7 +1,7 @@
 /* [wk/io.h wk 15.05.93] Redirector for io.h
  *	Copyright (c) 1988-93 by Werner Koch (dd9jn)
  * This file is part of WkLib. See wk/lib.h for details.
- * $Id: io.h,v 1.12 1996/07/16 10:33:47 wernerk Exp $
+ * $Id: io.h,v 1.15 1997/05/21 14:46:22 wk Exp $
  */
 
 #ifndef HDR_WK_IO
@@ -20,6 +20,10 @@
     #endif
 #else
     #include <io.h>
+    #ifdef EMX
+      int getpid(void);
+      int getppid(void);
+    #endif
     #ifndef F_OK
       #define F_OK  0	    /* test for existence of file */
     #endif
@@ -35,6 +39,15 @@
     #ifdef __WATCOMC__
       #include <process.h>
       typedef int pid_t;
+      #ifdef NETWARE
+	/*-- nwmiss.c --*/
+	pid_t getpid(void);
+	pid_t getppid(void);
+      #endif
+    #elif __MINGW32__
+      #include <process.h>
+      typedef int pid_t;
+      #define getpid() _getpid()
     #endif
 #endif
 
