@@ -37,7 +37,7 @@
  */
 
 #include <wk/tailor.h>
-RCSID("$Id: regexp.c,v 1.6 1996/01/25 20:16:48 wernerk Exp $")
+RCSID("$Id: regexp.c,v 1.7 1996/10/07 19:44:08 wk Exp $")
 #include <stdio.h>
 #include <ctype.h>
 #include <stdlib.h>
@@ -638,7 +638,8 @@ static char *regatom(int *flagp)
 					/* FIXME: Someday handle \1, \2, ... */
 						goto done; /* Not quoted */
 					default:
-						/* Backup point is \, scan							 * point is after it. */
+						/* Backup point is \, scan
+						 * point is after it. */
 						regprev = regparse;
 						regparse++;
 						continue;	/* NOT break; */
@@ -877,8 +878,16 @@ static int regmatch(char *prog)
 #endif
 	while (scan != NULL) {
 #ifdef DEBUG
-		if (regNarrate)
+		if (regNarrate) {
+		    switch(OP(scan)) {
+		      case EXACTLY:
+			fprintf(stderr, "%s(%s)...\n", regprop(scan),
+				       OPERAND(scan));
+			break;
+		      default:
 			fprintf(stderr, "%s...\n", regprop(scan));
+		    }
+		}
 #endif
 		next = regnext(scan);
 
